==> jc-1.4.0.tar.gz: javax/xml/xpath/XPathConstants.h <==
// public class javax.xml.xpath.XPathConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 737a8c3ca2836309 javax_xml_xpath_XPathConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_xpath_XPathConstants_H_
#define _JC_javax_xml_xpath_XPathConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;

// Typedefs
typedef struct _jc_javax_xml_xpath_XPathConstants$sub_refs	_jc_javax_xml_xpath_XPathConstants$sub_refs;
typedef struct _jc_javax_xml_xpath_XPathConstants$sub_nonrefs	_jc_javax_xml_xpath_XPathConstants$sub_nonrefs;
typedef struct _jc_javax_xml_xpath_XPathConstants$refs	_jc_javax_xml_xpath_XPathConstants$refs;
typedef struct _jc_javax_xml_xpath_XPathConstants$nonrefs	_jc_javax_xml_xpath_XPathConstants$nonrefs;
typedef struct _jc_javax_xml_xpath_XPathConstants$object	_jc_javax_xml_xpath_XPathConstants$object;

typedef struct _jc_javax_xml_xpath_XPathConstants$fields_struct	_jc_javax_xml_xpath_XPathConstants$fields_struct;
typedef const struct _jc_javax_xml_xpath_XPathConstants$vmethods	_jc_javax_xml_xpath_XPathConstants$vmethods;
typedef const struct _jc_javax_xml_xpath_XPathConstants$vtable	_jc_javax_xml_xpath_XPathConstants$vtable;
typedef const struct _jc_javax_xml_xpath_XPathConstants$vtype	_jc_javax_xml_xpath_XPathConstants$vtype;

// Class fields structure
struct _jc_javax_xml_xpath_XPathConstants$fields_struct {
	struct _jc_javax_xml_namespace_QName$object	*BOOLEAN;
	struct _jc_java_lang_String$object	*DOM__5fOBJECT__5fMODEL;
	struct _jc_javax_xml_namespace_QName$object	*NODE;
	struct _jc_javax_xml_namespace_QName$object	*NODESET;
	struct _jc_javax_xml_namespace_QName$object	*NUMBER;
	struct _jc_javax_xml_namespace_QName$object	*STRING;
};
extern _jc_javax_xml_xpath_XPathConstants$fields_struct _jc_javax_xml_xpath_XPathConstants$class_fields;

// Constructors
extern void _jc_javax_xml_xpath_XPathConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_xpath_XPathConstants$object *);

// Static methods
extern void _jc_javax_xml_xpath_XPathConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_xml_xpath_XPathConstants$vmethods {
};

// Vtable
struct _jc_javax_xml_xpath_XPathConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_xpath_XPathConstants$vmethods	javax_xml_xpath_XPathConstants;
};

// Vtype
struct _jc_javax_xml_xpath_XPathConstants$vtype {
	_jc_type			type;
	_jc_javax_xml_xpath_XPathConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_xpath_XPathConstants$refs {
    _jc_javax_xml_xpath_XPathConstants$sub_refs	javax_xml_xpath_XPathConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_xpath_XPathConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_xpath_XPathConstants$sub_nonrefs	javax_xml_xpath_XPathConstants;
};

// Object instance structure
struct _jc_javax_xml_xpath_XPathConstants$object {
	_jc_javax_xml_xpath_XPathConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_xpath_XPathConstants$vtype	*vtype;
	_jc_javax_xml_xpath_XPathConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_xpath_XPathConstants$vtype _jc_javax_xml_xpath_XPathConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_xpath_XPathConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_xpath_XPathConstants$class_object;

#endif	/* _JC_javax_xml_xpath_XPathConstants_H_ */

==> jc-1.4.6.tar.gz: javax/xml/xpath/XPathConstants.h <==
// public class javax.xml.xpath.XPathConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 737a8c3ca2836309 javax_xml_xpath_XPathConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_xpath_XPathConstants_H_
#define _JC_javax_xml_xpath_XPathConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;

// Typedefs
typedef struct _jc_javax_xml_xpath_XPathConstants$sub_refs	_jc_javax_xml_xpath_XPathConstants$sub_refs;
typedef struct _jc_javax_xml_xpath_XPathConstants$sub_nonrefs	_jc_javax_xml_xpath_XPathConstants$sub_nonrefs;
typedef struct _jc_javax_xml_xpath_XPathConstants$refs	_jc_javax_xml_xpath_XPathConstants$refs;
typedef struct _jc_javax_xml_xpath_XPathConstants$nonrefs	_jc_javax_xml_xpath_XPathConstants$nonrefs;
typedef struct _jc_javax_xml_xpath_XPathConstants$object	_jc_javax_xml_xpath_XPathConstants$object;

typedef struct _jc_javax_xml_xpath_XPathConstants$fields_struct	_jc_javax_xml_xpath_XPathConstants$fields_struct;
typedef const struct _jc_javax_xml_xpath_XPathConstants$vmethods	_jc_javax_xml_xpath_XPathConstants$vmethods;
typedef const struct _jc_javax_xml_xpath_XPathConstants$vtable	_jc_javax_xml_xpath_XPathConstants$vtable;
typedef const struct _jc_javax_xml_xpath_XPathConstants$vtype	_jc_javax_xml_xpath_XPathConstants$vtype;

// Class fields structure
struct _jc_javax_xml_xpath_XPathConstants$fields_struct {
	struct _jc_javax_xml_namespace_QName$object	*BOOLEAN;
	struct _jc_java_lang_String$object	*DOM__5fOBJECT__5fMODEL;
	struct _jc_javax_xml_namespace_QName$object	*NODE;
	struct _jc_javax_xml_namespace_QName$object	*NODESET;
	struct _jc_javax_xml_namespace_QName$object	*NUMBER;
	struct _jc_javax_xml_namespace_QName$object	*STRING;
};
extern _jc_javax_xml_xpath_XPathConstants$fields_struct _jc_javax_xml_xpath_XPathConstants$class_fields;

// Constructors
extern void _jc_javax_xml_xpath_XPathConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_xpath_XPathConstants$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_xml_xpath_XPathConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_xpath_XPathConstants$vmethods {
};

// Vtable
struct _jc_javax_xml_xpath_XPathConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_xpath_XPathConstants$vmethods	javax_xml_xpath_XPathConstants;
};

// Vtype
struct _jc_javax_xml_xpath_XPathConstants$vtype {
	_jc_type			type;
	_jc_javax_xml_xpath_XPathConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_xpath_XPathConstants$refs {
    _jc_javax_xml_xpath_XPathConstants$sub_refs	javax_xml_xpath_XPathConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_xpath_XPathConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_xpath_XPathConstants$sub_nonrefs	javax_xml_xpath_XPathConstants;
};

// Object instance structure
struct _jc_javax_xml_xpath_XPathConstants$object {
	_jc_javax_xml_xpath_XPathConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_xpath_XPathConstants$vtype	*vtype;
	_jc_javax_xml_xpath_XPathConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_xpath_XPathConstants$vtype _jc_javax_xml_xpath_XPathConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_xpath_XPathConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_xpath_XPathConstants$class_object;

#endif	/* _JC_javax_xml_xpath_XPathConstants_H_ */
